
Serialization library for multi-dimensional arrays (native-python and NumPy) structured in key-value format.

Links
-----
GitHub: https://github.com/signalarray/xmat
Documentation: https://https://xmat.readthedocs.io
